==> billogram-foundation-4.4.0.tgz: package/modules/components/lightbox/FoundationOverlayLayout.js <==
import React, { PropTypes } from 'react';
import purebem from 'purebem';

import './FoundationOverlayLayout.less';


const block = purebem.of('foundation-overlay-layout');

const FoundationOverlayLayout = React.createClass({

    propTypes: {
        children: PropTypes.node
    },

    getDefaultProps() {
        return {
            children: null
        };
    },

    componentDidMount() {
        this.offset = window.pageYOffset;
        const top = this.offset > 0 ? this.offset * -1 : this.offset;

        const body = document.body || document.getElementsByTagName('body')[0];
        // might have to use polyfill for older browsers.
        body.classList.add('overlay-layout');

        this.bodyStyleLeft = body.style.left;
        this.bodyStyleTop = body.style.top;
        body.style.left = 0;
        body.style.top = `${top}px`;
    },

    componentWillUnmount() {
        const body = document.body || document.getElementsByTagName('body')[0];
        if (body.classList.contains('overlay-layout')) {
            body.classList.remove('overlay-layout');
            body.style.left = this.bodyStyleLeft;
            body.style.top = this.bodyStyleTop;

            window.scrollTo(0, this.offset);
        }
    },

    render() {
        return (
            <div className={ block() }>
                <div className={ block('content') }>
                    { this.props.children }
                </div>
            </div>
        );
    }

});

export default FoundationOverlayLayout;

==> billogram-foundation-4.4.2.tgz: package/modules/components/lightbox/FoundationOverlayLayout.js <==
import React, { PropTypes } from 'react';
import purebem from 'purebem';

import './FoundationOverlayLayout.less';


const block = purebem.of('foundation-overlay-layout');

const FoundationOverlayLayout = React.createClass({

    propTypes: {
        children: PropTypes.node,
        hasNavigation: PropTypes.bool
    },

    getDefaultProps() {
        return {
            children: null,
            hasNavigation: true
        };
    },

    componentDidMount() {
        this.offset = window.pageYOffset;
        const top = this.offset > 0 ? this.offset * -1 : this.offset;

        const body = document.body || document.getElementsByTagName('body')[0];
        // might have to use polyfill for older browsers.
        body.classList.add('overlay-layout');

        this.bodyStyleLeft = body.style.left;
        this.bodyStyleTop = body.style.top;
        body.style.left = 0;
        body.style.top = `${top}px`;
    },

    componentWillUnmount() {
        const body = document.body || document.getElementsByTagName('body')[0];
        if (body.classList.contains('overlay-layout')) {
            body.classList.remove('overlay-layout');
            body.style.left = this.bodyStyleLeft;
            body.style.top = this.bodyStyleTop;

            window.scrollTo(0, this.offset);
        }
    },

    render() {
        const { hasNavigation: navigation } = this.props;
        return (
            <div className={ block({ navigation }) }>
                <div className={ block('content') }>
                    { this.props.children }
                </div>
            </div>
        );
    }

});

export default FoundationOverlayLayout;
